import { renderless, api } from '@opentinyvue/vue-renderless/cascader/vue';
import { defineComponent, props, directive, setup } from '@opentinyvue/vue-common';
import { Clickoutside, HighlightQuery } from '@opentinyvue/vue-directive';
import Input from '@opentinyvue/vue-input';
import Tag from '@opentinyvue/vue-tag';
import Scrollbar from '@opentinyvue/vue-scrollbar';
import CascaderPanel from '@opentinyvue/vue-cascader-panel';
import FilterBox from '@opentinyvue/vue-filter-box';
import Tooltip from '@opentinyvue/vue-tooltip';
import { iconClose, IconTriangleDown, IconUpWard, iconYes } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/cascader/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "options", "props", "size", "placeholder", "disabled", "clearable", "filterable", "filterMethod", "separator", "showAllLevels", "collapseTags", "debounce", "beforeFilter", "popperClass", "placement", "popperOptions", "visibleArrow", "offset", "boundariesPadding", "arrowOffset", "popperAppendToBody", "autoSize", "displayOnly", "shape", "label", "tip", "hoverExpand", "blank", "changeCompat"]),
  emits: ["update:modelValue", "change", "visible-change", "focus", "blur", "expand-change", "active-item-change", "remove-tag", "created"],
  directives: _extends({}, directive({
    Clickoutside
  }), {
    HighlightQuery
  }),
  provide: function provide() {
    return {
      cascaderRoot: this
    };
  },
  components: {
    TinyInput: Input,
    TinyTag: Tag,
    TinyScrollbar: Scrollbar,
    TinyFilterBox: FilterBox,
    TinyCascaderPanel: CascaderPanel,
    IconClose: iconClose(),
    IconChevronDown: IconTriangleDown(),
    IconChevronUp: IconUpWard(),
    IconYes: iconYes(),
    TinyTooltip: Tooltip
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: function value() {
        return _vm.toggleDropDownVisible(false);
      },
      expression: "() => toggleDropDownVisible(false)"
    }],
    ref: "reference",
    class: ["tiny-cascader", _vm.state.realSize && "tiny-cascader--" + _vm.state.realSize, {
      "is-disabled": _vm.state.isDisabled
    }, {
      "tiny-cascader-multiple": _vm.state.multiple
    }, {
      "is-display-only": _vm.state.isDisplayOnly
    }, {
      "show-auto-width": _vm.state.showAutoWidth
    }, {
      "is-hover-expand": _vm.hoverExpand
    }],
    on: {
      "mouseenter": function mouseenter($event) {
        _vm.state.inputHover = true;
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.inputHover = false;
      },
      "click": function click() {
        return _vm.toggleDropDownVisible(_vm.state.readonly ? void 0 : true);
      },
      "keydown": _vm.handleKeyDown
    }
  }, [_vm.shape === "filter" ? _c("tiny-filter-box", {
    attrs: {
      "show-close": _vm.clearable,
      "placeholder": _vm.placeholder,
      "disabled": _vm.state.isDisabled,
      "label": _vm.label,
      "tip": _vm.tip,
      "value": _vm.state.multiple ? _vm.state.presentTags.map(function(item) {
        return item.text;
      }).join("; ") : _vm.state.inputValue,
      "drop-down-visible": _vm.state.dropDownVisible,
      "blank": _vm.blank
    },
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.toggleDropDownVisible();
      }
    }
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-cascader-content"
  }, [_vm.shape !== "filter" ? _c("tiny-input", {
    ref: "input",
    class: {
      "is-focus": _vm.state.dropDownVisible
    },
    attrs: {
      "model-value": _vm.state.multiple && _vm.filterable ? "" : _vm.state.inputValues,
      "size": _vm.state.realSize,
      "placeholder": _vm.state.multiple && _vm.filterable ? "" : _vm.state.placeholder,
      "readonly": _vm.state.readonly,
      "disabled": _vm.state.isDisabled,
      "display-only": _vm.displayOnly,
      "display-only-content": _vm.state.multiple ? _vm.state.presentTags.map(function(item) {
        return item.text;
      }).join("; ") : "",
      "validate-event": false
    },
    on: {
      "focus": _vm.handleFocus,
      "blur": _vm.handleBlur,
      "update:modelValue": function updateModelValue(val) {
        return _vm.handleInput(val, {});
      }
    },
    scopedSlots: _vm._u([{
      key: "suffix",
      fn: function fn() {
        return [_vm.state.clearBtnVisible ? _c("icon-close", {
          key: "clear",
          class: ["tiny-input__icon", "tiny-input__icon-close"],
          on: {
            "click": function click($event) {
              $event.stopPropagation();
              return _vm.handleClear.apply(null, arguments);
            }
          }
        }) : _c(_vm.state.dropDownVisible ? "icon-chevron-up" : "icon-chevron-down", {
          key: "arrow-down",
          tag: "component",
          class: ["tiny-input__icon", _vm.state.dropDownVisible && "is-reverse"],
          on: {
            "click": function click($event) {
              $event.stopPropagation();
              return _vm.toggleDropDownVisible();
            }
          }
        })];
      },
      proxy: true
    }], null, false, 1295602185)
  }) : _vm._e(), _vm.state.multiple && !_vm.state.isDisplayOnly && !_vm.shape ? _c("div", {
    ref: "tags-content",
    staticClass: "tiny-cascader__tags",
    class: {
      "is-expand-content": _vm.hoverExpand && !_vm.state.isDisabled && (_vm.state.inputHover || _vm.state.dropDownVisible)
    }
  }, [_vm.hoverExpand ? _c("tiny-tag", {
    class: ["tiny-cascader__tags-collapse", {
      "is-hidden": _vm.state.isHidden
    }],
    attrs: {
      "type": _vm.state.tagTypeWhenMultiple,
      "closable": false,
      "size": _vm.state.tagSize
    }
  }, [_vm._v("+ " + _vm._s(_vm.state.collapseTagsLength) + " ")]) : _vm._e(), _vm._l(_vm.state.presentTags, function(tag, index) {
    return _c("tiny-tag", {
      key: tag.key,
      attrs: {
        "type": _vm.state.tagTypeWhenMultiple,
        "size": _vm.state.tagSize,
        "hit": tag.hitState,
        "closable": tag.closable,
        "disable-transitions": ""
      },
      on: {
        "close": function close($event) {
          return _vm.deleteTag(index);
        }
      },
      nativeOn: {
        "mouseenter": function mouseenter($event) {
          return _vm.handleMouseenter.apply(null, arguments);
        },
        "mouseleave": function mouseleave($event) {
          return _vm.handleMouseleave.apply(null, arguments);
        }
      }
    }, [_c("span", [_vm._v(_vm._s(tag.text))])]);
  }), _vm.filterable && !_vm.state.isDisabled ? _c("input", {
    directives: [{
      name: "model",
      rawName: "v-model.trim",
      value: _vm.state.inputValue,
      expression: "state.inputValue",
      modifiers: {
        "trim": true
      }
    }],
    staticClass: "tiny-cascader__search-input",
    attrs: {
      "type": "text",
      "placeholder": _vm.state.presentTags.length ? "" : _vm.placeholder
    },
    domProps: {
      "value": _vm.state.inputValue
    },
    on: {
      "input": [function($event) {
        if ($event.target.composing) return;
        _vm.$set(_vm.state, "inputValue", $event.target.value.trim());
      }, function(e) {
        return _vm.handleInput(_vm.state.inputValue, e);
      }],
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.toggleDropDownVisible(true);
      },
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "delete", [8, 46], $event.key, ["Backspace", "Delete", "Del"])) return null;
        return _vm.handleDelete.apply(null, arguments);
      },
      "blur": function blur($event) {
        return _vm.$forceUpdate();
      }
    }
  }) : _vm._e()], 2) : _vm._e()], 1), _c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "manual": true,
      "effect": "light",
      "content": _vm.state.tooltipContent,
      "placement": "top"
    },
    model: {
      value: _vm.state.tooltipVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tooltipVisible", $$v);
      },
      expression: "state.tooltipVisible"
    }
  }), _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-leave": _vm.handleDropdownLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.dropDownVisible,
      expression: "state.dropDownVisible"
    }],
    ref: "popper",
    class: ["tiny-popper", "tiny-cascader-dropdown", "tiny-cascader__dropdown", _vm.popperClass, {
      "is-auto-size": _vm.autoSize,
      "is-multiple": _vm.state.multiple
    }],
    on: {
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_c("tiny-cascader-panel", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: !_vm.state.filtering,
      expression: "!state.filtering"
    }],
    ref: "panel",
    attrs: {
      "options": _vm.options,
      "props": _vm.state.config,
      "border": false,
      "render-label": _vm.slots.default,
      "onlyUsePanel": false
    },
    on: {
      "expand-change": _vm.handleExpandChange,
      "close": function close($event) {
        return _vm.toggleDropDownVisible(false);
      },
      "load-data": _vm.computePresentContent
    },
    model: {
      value: _vm.state.checkedValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "checkedValue", $$v);
      },
      expression: "state.checkedValue"
    }
  }), _vm.filterable ? _c("tiny-scrollbar", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.filtering,
      expression: "state.filtering"
    }],
    ref: "suggestionPanel",
    staticClass: "tiny-cascader__suggestion-panel",
    attrs: {
      "tag": "ul",
      "view-class": "tiny-cascader__suggestion-list"
    },
    on: {
      "keydown": _vm.handleSuggestionKeyDown
    },
    scopedSlots: _vm._u([_vm.state.suggestions.length ? {
      key: "default",
      fn: function fn() {
        return _vm._l(_vm.state.suggestions, function(item, index) {
          return _c("li", {
            directives: [{
              name: "highlight-query",
              rawName: "v-highlight-query",
              value: _vm.state.multiple ? _vm.state.presentText : _vm.state.inputValue,
              expression: "state.multiple ? state.presentText : state.inputValue"
            }],
            key: item.uid,
            class: ["tiny-cascader__suggestion-item", item.checked && "is-checked"],
            attrs: {
              "tabindex": -1
            },
            on: {
              "click": function click($event) {
                return _vm.handleSuggestionClick(index);
              }
            }
          }, [_vm._t("filter", function() {
            return [_c("span", [_vm._v(_vm._s(item.text))])];
          }, {
            "item": item.text
          }), item.checked ? _c("icon-yes", {
            staticClass: "icon-check"
          }) : _vm._e()], 2);
        });
      },
      proxy: true
    } : null], null, true)
  }, [!_vm.state.suggestions.length ? _vm._t("empty", function() {
    return [_c("li", {
      staticClass: "tiny-cascader__empty-text"
    }, [_vm._v(" " + _vm._s(_vm.t("ui.cascader.noMatch")) + " ")])];
  }) : _vm._e()], 2) : _vm._e()], 1)])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
